# unit tests do not finish or crash the JVM
%bcond_with tests

%global srcname commons-io

Name:           apache-commons-io
Epoch:          1
Version:        2.8.0
Release:        %mkrel 1
Summary:        Utilities to assist with developing IO functionality
Group:          Development/Java
License:        ASL 2.0

URL:            https://commons.apache.org/io
Source0:        https://archive.apache.org/dist/commons/io/source/%{srcname}-%{version}-src.tar.gz

BuildArch:      noarch

BuildRequires:  maven-local
BuildRequires:  mvn(org.apache.commons:commons-parent:pom:)
BuildRequires:  mvn(org.apache.maven.plugins:maven-antrun-plugin)

%if %{with tests}
BuildRequires:  mvn(junit:junit)
BuildRequires:  mvn(org.junit.jupiter:junit-jupiter)
BuildRequires:  mvn(org.mockito:mockito-core)
BuildRequires:  mvn(org.apache.maven.surefire:surefire-junit-platform)
%endif

%description
Commons-IO contains utility classes, stream implementations,
file filters, and endian classes. It is a library of utilities
to assist with developing IO functionality.


%package javadoc
Summary:        Javadoc for %{name}

%description javadoc
API documentation for %{name}.


%prep
%setup -q -n %{srcname}-%{version}-src
sed -i 's/\r//' *.txt

%if %{with tests}
# com.google.jimfs:jimfs is not packaged for fedora
%pom_remove_dep com.google.jimfs:jimfs
rm src/test/java/org/apache/commons/io/input/ReversedLinesFileReaderTestParamFile.java

# junit-pioneer is not packaged for fedora
%pom_remove_dep :junit-pioneer
rm src/test/java/org/apache/commons/io/input/XmlStreamReaderTest.java
rm src/test/java/org/apache/commons/io/output/XmlStreamWriterTest.java
%endif

%mvn_file  : commons-io %{name}
%mvn_alias : org.apache.commons:


%build
%if %{with tests}
%mvn_build -- -Dcommons.osgi.symbolicName=org.apache.commons.io
%else
%mvn_build -f -- -Dcommons.osgi.symbolicName=org.apache.commons.io
%endif


%install
%mvn_install


%files -f .mfiles
%license LICENSE.txt NOTICE.txt
%doc RELEASE-NOTES.txt

%files javadoc -f .mfiles-javadoc
%license LICENSE.txt NOTICE.txt



%changelog
* Mon Dec 14 2020 neoclust <neoclust> 1:2.8.0-1.mga8
+ Revision: 1657172
- New version 2.8.0

* Sun Aug 23 2020 neoclust <neoclust> 1:2.6-6.mga8
+ Revision: 1618237
- Rebuild against java11

* Sat Feb 15 2020 umeabot <umeabot> 1:2.6-5.mga8
+ Revision: 1527535
- Mageia 8 Mass Rebuild

* Thu Jul 18 2019 daviddavid <daviddavid> 1:2.6-4.mga8
+ Revision: 1422299
- Rebuild to regenerate OSGi metadata

* Wed Dec 12 2018 daviddavid <daviddavid> 1:2.6-3.mga7
+ Revision: 1340713
- rebuild against fixed apache-commons-parent (fixes osgi meta)
- remove previous provide osgi(org.apache.commons.io)

* Mon Nov 26 2018 wally <wally> 1:2.6-2.mga7
+ Revision: 1335288
- provide osgi(org.apache.commons.io) to make eclipse installable again

* Sun Nov 18 2018 guillomovitch <guillomovitch> 1:2.6-1.mga7
+ Revision: 1330826
- new version 2.6

* Tue Sep 18 2018 umeabot <umeabot> 1:2.4-12.mga7
+ Revision: 1259537
- Mageia 7 Mass Rebuild

* Wed May 17 2017 neoclust <neoclust> 1:2.4-11.mga6
+ Revision: 1102525
- Rebuild against fixed apache-commons-parents

* Wed Mar 02 2016 neoclust <neoclust> 1:2.4-10.mga6
+ Revision: 982569
- Second rebuild of the java stack

* Tue Feb 23 2016 daviddavid <daviddavid> 1:2.4-9.mga6
+ Revision: 977196
- rebuild against current java stack

* Sun Feb 21 2016 neoclust <neoclust> 1:2.4-5.mga6
+ Revision: 975485
- First rebuild of the java stack
- sync package apache-commons-io with fedora
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild
+ dmorgan <dmorgan>
- Restore from Obsolete
+ sander85 <sander85>
- Depends on broken java stack

* Wed Oct 15 2014 umeabot <umeabot> 1:2.4-8.mga5
+ Revision: 748939
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1:2.4-7.mga5
+ Revision: 677808
- Mageia 5 Mass Rebuild

* Tue Nov 26 2013 dmorgan <dmorgan> 1:2.4-6.mga4
+ Revision: 553584
- Disable tests

* Tue Oct 22 2013 umeabot <umeabot> 1:2.4-5.mga4
+ Revision: 545636
- Mageia 4 Mass Rebuild

* Wed Oct 16 2013 dmorgan <dmorgan> 1:2.4-4.mga4
+ Revision: 501469
- Build with xmvn
- Add Provides/Obsoletes for jakarta-commons-io

* Fri Jan 11 2013 umeabot <umeabot> 1:2.4-2.mga3
+ Revision: 345745
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Sep 08 2012 dmorgan <dmorgan> 1:2.4-1.mga3
+ Revision: 289701
- New version 2.4

* Mon Jul 16 2012 dmorgan <dmorgan> 1:2.1-1.mga3
+ Revision: 271292
- New version 2.1

* Sat Jul 23 2011 dmorgan <dmorgan> 1:2.0.1-4.mga3
+ Revision: 128024
- Fix build with maven3
    - Use new add_maven_depmap macro

* Wed Apr 27 2011 dmorgan <dmorgan> 1:2.0.1-3.mga1
+ Revision: 92236
- Rebuild after bootstrapping
- imported package apache-commons-io


* Mon Feb 07 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1:2.0.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Tue Jan 18 2011 Stanislav Ochotnicky <sochotnicky@redhat.com> - 1:2.0.1-1
- Update to 2.0.1
- Versionless jars & javadocs
- Use maven 3 to build
- Use apache-commons-parent for BR

* Fri Oct 22 2010 Chris Spike <chris.spike@arcor.de> 1:2.0-1
- Updated to 2.0
- Cleaned up BRs

* Thu Jul  8 2010 Stanislav Ochotnicky <sochotnicky@redhat.com> - 1:1.4-6
- Add license to javadoc subpackage

* Fri May 21 2010 Stanislav Ochotnicky <sochotnicky@redhat.com> - 1:1.4-5
- Correct depmap filename for backward compatibility

* Mon May 17 2010 Stanislav Ochotnicky <sochotnicky@redhat.com> - 1:1.4-4
- Fix maven depmap JPP name to short_name

* Wed May 12 2010 Stanislav Ochotnicky <sochotnicky@redhat.com> - 1:1.4-3
- Add obsoletes to javadoc sub-package

* Wed May 12 2010 Stanislav Ochotnicky <sochotnicky@redhat.com> - 1:1.4-2
- Add symlink to short_name.jar
- Fix mavendepmapfragdir wildcard

* Tue May 11 2010 Stanislav Ochotnicky <sochotnicky@redhat.com> - 1:1.4-1
- Rename and rebase of jakarta-commons-io
- Clean up whole spec
